'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Track = _react2.default.createClass({
  displayName: 'Track',

  getInitialState: function getInitialState() {
    return { playingTrack: null, isPlaying: false };
  },
  getDuration: function getDuration(ms) {
    var min = ms / 1000 / 60 << 0;
    var sec = ms / 1000 % 60;

    return Math.round(min, -2) + ':' + (Math.round(sec, -2) < 10 ? '0' + Math.round(sec, -2) : Math.round(sec, -2));
  },
  getDefaultProps: function getDefaultProps() {
    return {
      onPlayingStatusChange: undefined
    };
  },
  propTypes: {
    onPlayingStatusChange: _react2.default.PropTypes.func, //handler on playing status change, function(isPlaying, audioTrack, spotifyTrack),
    tooltip: _react2.default.PropTypes.string.isRequired,
    track: _react2.default.PropTypes.object.isRequired
  },
  playTrack: function playTrack(event) {
    var trackUrl = event.target.dataset.url;
    this.setState({ isPlaying: true });
    var that = this;
    if (this.state.playingTrack === null) {
      //first time track is played
      this.setState({ isPlaying: true, playingTrack: new Audio(trackUrl) }, function () {
        this.state.playingTrack.play();
        this.props.onPlayingStatusChange(true, this.state.playingTrack, this.props.track);
        this.state.playingTrack.addEventListener('ended', function () {
          that.setState({ isPlaying: false });
          that.props.onPlayingStatusChange(false, that.state.playingTrack, that.props.track);
        });
      });
    } else if (this.state.playingTrack.paused) {
      this.state.playingTrack.play();
      this.setState({ isPlaying: true }, function () {
        that.props.onPlayingStatusChange(true, this.state.playingTrack, this.props.track);
      });
    } else {
      this.state.playingTrack.pause();
      this.setState({ isPlaying: false }, function () {
        that.props.onPlayingStatusChange(false, this.state.playingTrack, this.props.track);
      });
    }
  },
  render: function render() {
    var playButtonClassNames = this.state.isPlaying ? 'fa fa-pause' : 'fa fa-play';
    var playButtonStyle = { cursor: 'default' };
    return _react2.default.createElement(
      'li',
      {
        className: 'list-group-item'
      },
      _react2.default.createElement(
        'span',
        { className: 'badge' },
        _react2.default.createElement('i', {
          className: playButtonClassNames,
          'data-url': this.props.track.preview_url,
          onClick: this.playTrack,
          style: playButtonStyle,
          title: this.props.tooltip
        })
      ),
      this.props.track.track_number,
      '. ',
      this.props.track.name,
      ' (',
      this.getDuration(this.props.track.duration_ms),
      ')'
    );
  }
});
module.exports = Track;